# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.0.0-beta.1

import winrt.system
from winrt import _winrt_windows_ui_xaml_shapes

__all__ = [
    "Ellipse",
    "Line",
    "Path",
    "Polygon",
    "Polyline",
    "Rectangle",
    "Shape",
]

Ellipse = _winrt_windows_ui_xaml_shapes.Ellipse
Line = _winrt_windows_ui_xaml_shapes.Line
Path = _winrt_windows_ui_xaml_shapes.Path
Polygon = _winrt_windows_ui_xaml_shapes.Polygon
Polyline = _winrt_windows_ui_xaml_shapes.Polyline
Rectangle = _winrt_windows_ui_xaml_shapes.Rectangle
Shape = _winrt_windows_ui_xaml_shapes.Shape
